CliArgs

Struct CliArgs 

pub struct CliArgs {
    pub address: SocketAddr,
    pub tls_cert: Option<PathBuf>,
    pub tls_key: Option<PathBuf>,
    pub http1_max_buf_size: Option<usize>,
    pub find_free_port: bool,
    pub max_instance_reuse_count: Option<Range<usize>>,
    pub max_instance_concurrent_reuse_count: Option<Range<usize>>,
    pub request_timeout: Option<Range<Duration>>,
    pub idle_instance_timeout: Range<Duration>,
}

Fields

address: SocketAddr

IP address and port to listen on

tls_cert: Option<PathBuf>

The path to the certificate to use for https, if this is not set, normal http will be used. The cert should be in PEM format

tls_key: Option<PathBuf>

The path to the certificate key to use for https, if this is not set, normal http will be used. The key should be in PKCS#8 format

http1_max_buf_size: Option<usize>

Sets the maximum buffer size (in bytes) for the HTTP connection. The minimum value allowed is 8192.

find_free_port: boolmax_instance_reuse_count: Option<Range<usize>>

Maximum number of requests to send to a single component instance before dropping it.

This defaults to 1 for WASIp2 components and 128 for WASIp3 components. As of this writing, setting it to more than 1 will have no effect for WASIp2 components, but that may change in the future.

This may be specified either as an integer value or as a range, e.g. 1..8. If it’s a range, a number will be selected from that range at random for each new instance.

max_instance_concurrent_reuse_count: Option<Range<usize>>

Maximum number of concurrent requests to send to a single component instance.

This defaults to 1 for WASIp2 components and 16 for WASIp3 components. Note that setting it to more than 1 will have no effect for WASIp2 components since they cannot be called concurrently.

This may be specified either as an integer value or as a range, e.g. 1..8. If it’s a range, a number will be selected from that range at random for each new instance.

request_timeout: Option<Range<Duration>>

Request timeout to enforce.

As of this writing, this only affects WASIp3 components.

A number with no suffix or with an s suffix is interpreted as seconds; other accepted suffixes include ms (milliseconds), us or μs (microseconds), and ns (nanoseconds).

This may be specified either as a single time value or as a range, e.g. 1..8s. If it’s a range, a value will be selected from that range at random for each new instance.

idle_instance_timeout: Range<Duration>

Time to hold an idle component instance for possible reuse before dropping it.

A number with no suffix or with an s suffix is interpreted as seconds; other accepted suffixes include ms (milliseconds), us or μs (microseconds), and ns (nanoseconds).

This may be specified either as a single time value or as a range, e.g. 1..8s. If it’s a range, a value will be selected from that range at random for each new instance.